# -*- coding: utf-8 -*-
import sys
from urlparse import parse_qsl
import urllib
import requests
import xbmcgui
import xbmcplugin
import xbmcaddon
import xbmc
import inputstreamhelper

base_url = sys.argv[0]
addon_handle = int(sys.argv[1])
params = dict(parse_qsl(sys.argv[2][1:]))
addon = xbmcaddon.Addon(id='plugin.video.pilot.wp')

main_guest_url = 'https://pilot.wp.pl/api/guest/channels/list'
video_guest_url = 'https://pilot.wp.pl/api/v1/guest/channel/'
login_url = 'https://pilot.wp.pl/api/v1/user_auth/login'
main_url = 'https://pilot.wp.pl/api/channels/list/android-plus'
video_url = 'https://pilot.wp.pl/api/v1/channel/'
close_stream_url = 'https://pilot.wp.pl/api/v1/channels/close'

headers = {
    'accept': 'application/json',
    'user-agent': 'ExoMedia 4.2.0 (42000) / Android 5.0 / Google Nexus 4 - 5.0.0 - API 21 - 768x1280',
    'accept-encoding': 'gzip'
}

username = addon.getSetting('username')
password = addon.getSetting('password')
sessionid = params.get('sessionid', '')


def build_url(query):
    return base_url + '?' + urllib.urlencode(query)


def add_item(name, image, is_folder, is_playble, payload, plot=''):
    list_item = xbmcgui.ListItem(label=name)

    if is_playble:
        list_item.setProperty("IsPlayable", 'true')
    else:
        list_item.setProperty("IsPlayable", 'false')

    list_item.setInfo(type='video', infoLabels={'title': name, 'sorttitle': name, 'plot': plot})
    list_item.setArt({'thumb': image, 'poster': image, 'banner': image})
    xbmcplugin.addDirectoryItem(
        handle=addon_handle,
        url=build_url(payload),
        listitem=list_item,
        isFolder=is_folder
    )


def login():
    if len(password) > 0 and len(username) > 0:
        data = {'device': 'android', 'login': username, 'password': password}

        response = requests.post(
            login_url,
            json=data,
            verify=False,
            headers=headers
        )

        meta = response.json().get('_meta', None)
        if meta is not None:
            if meta.get('error', {}).get('name', None) is not None:
                xbmcgui.Dialog().ok('Nieudane logowanie', 'Sprawdz login i hasło w ustawieniach wtyczki.')
                return ''

        return response.cookies['netviapisessid']
    else:
        return ''


def play(retry=False):
    id = params.get('id', None)
    data = {'format_id': '2', 'device': 'android'}

    print len(sessionid)

    if len(sessionid) > 0:
        url = video_url + id
        cookies = {'netviapisessid': sessionid}
    else:
        url = video_guest_url + id
        cookies = {}

    response = requests.get(
        url,
        params=data,
        verify=False,
        headers=headers,
        cookies=cookies
    ).json()

    meta = response.get('_meta', None)
    if meta is not None:
        token = meta.get('error', {}).get('info', {}).get('stream_token', None)
        if token is not None:
            json = {'channelId': id, 't': token}
            response = requests.post(
                close_stream_url,
                json=json,
                verify=False,
                headers=headers,
                cookies=cookies
            ).json()
            if response.get('data', {}).get('status', '') == 'ok' and not retry:
                play(True)
                return

    manifest = response.get('data', None).get('stream_channel', None).get('url_base', None)
    play_item = xbmcgui.ListItem(path=manifest)
    xbmcplugin.setResolvedUrl(addon_handle, True, listitem=play_item)


def home():
    global sessionid
    sessionid = login()

    if len(sessionid) > 0:
        response = requests.get(
            main_url,
            verify=False,
            headers=headers,
            cookies={'netviapisessid': sessionid}
        ).json()
        items = response.get('channels', None)
    else:
        data = {'device': 'android-plus'}

        response = requests.get(
            main_guest_url,
            params=data,
            verify=False,
            headers=headers
        ).json()
        items = response.get('channels', None)

    display(items)


def display(items):
    for item in items:
        if item.get('access_status', '') != 'unsubscribed':
            title = item.get('name', '')
            icon = item.get('thumbnail_mobile', '')
            id = item.get('id', None)
            add_item(title, icon, False, True, {'mode': 'play', 'id': id, 'sessionid': sessionid})
    xbmcplugin.endOfDirectory(addon_handle)


if __name__ == '__main__':
    mode = params.get('mode', None)
    if not mode:
        home()
    elif mode == 'play':
        play()
